@@ -7,7 +7,7 @@ from djangoautoconf.auto_conf_utils import get_module_path, is_at_least_one_sub_
 from ufs_tools.short_decorator.ignore_exception import ignore_exc_with_result
 from djangoautoconf.auto_conf_utils import enum_modules
 from django.conf.urls import include
-from django.urls import path
+from django.urls import path, re_path
 from importlib import import_module
 
 try:
@@ -49,7 +49,7 @@ def add_url_pattern(default_url_root_path, urls_module):
                 include(admin.site.urls) or
                 RedirectView.as_view(url='/resource_bookmarks') etc.
     """
-    (get_custom_root_url_pattern_container()).insert_to_head(path(default_url_root_path, urls_module))
+    (get_custom_root_url_pattern_container()).insert_to_head(re_path(default_url_root_path, urls_module))
 
 
 def add_to_root_url_pattern(url_pattern_list):
@@ -132,8 +132,8 @@ def add_app_urls_no_exception(app):
                     include_param = include('%s.urls' % app)
                 add_url_pattern("^%s/" % app, include_param)
                 create_simple_menu(app)
-    except ImportError:
-        print("Import %s.urls failed (maybe %s.urls does not exists)." % (app, app))
+    #except ImportError:
+    #    print("Import %s.urls failed (maybe %s.urls does not exists)." % (app, app))
     except Exception as e:
         traceback.print_exc()
 
